#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-api-data
version:              0.4.3
visibility:           public
id:                   http-api-data-0.4.3-COBNmxSEM3z9aE2HjeY1Ym
key:                  http-api-data-0.4.3-COBNmxSEM3z9aE2HjeY1Ym
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  a05a6eabdec743ead7086217f73bd1bd
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-8.10.5/site-local/http-api-data-0.4.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/http-api-data-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/http-api-data-0.4.3
hs-libraries:         HShttp-api-data-0.4.3-COBNmxSEM3z9aE2HjeY1Ym
depends:
    attoparsec-0.14.1-IwUGXYiDhQIB5nUHrI5Wg8
    attoparsec-iso8601-1.0.2.0-EEIivOMvqjbBnaOglPUYro base-4.14.2.0
    base-compat-0.11.2-Eyusxyk2CrTGloLdon9bIK bytestring-0.10.12.0
    containers-0.6.4.1 cookie-0.4.5-DRjKUovO6l159RRdguKqPl
    hashable-1.3.2.0-L2CDkY7lZtECinpkHRj0mo
    http-types-0.12.3-Di0Av9jbzuQGAtr7LDgLEc
    tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV text-1.2.4.1
    time-compat-1.9.6-IRFK5lCmLyZ3fyMFVeT95j transformers-0.5.6.2
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O
    uuid-types-1.0.5-EgNl6lc27W27kXZpOd1nsx

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

